.. default-role:: math

Glossary
========

.. glossary::

    ADC
        analog-digital counts
    
    pdd
        power density distribution

    eta
        (`\eta`) upper clip-level
        
    epsilon
        (`\epsilon`) lower clip-level